@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2020-10-21
+# Release 2020-11-09
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.3.1
+MAKERESOLVEDEB_VERSION=1.4.0
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -150,6 +150,44 @@ process15() {
     create_directory ${DEB_DIR}/usr/lib/
     extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib/ libDaVinciPanelAPI.so
 
+    # Create udev rules
+    create_directory ${DEB_DIR}/lib/udev/rules.d
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
+EOF
+
+    # Create desktop shortcuts
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec=/opt/resolve/bin/resolve
+Icon=/opt/resolve/graphics/DV_Resolve.png
+Name=${RESOLVE_NAME}
+Terminal=false
+MimeType=application/x-resolveproj;
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
+Icon=/opt/resolve/graphics/DV_Panels.png
+Name=DaVinci Resolve Panels Setup
+Terminal=false
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+
     # Add postinst commands
     cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
 test -e /opt/resolve/configs/config.dat || cp /opt/resolve/configs/config.dat-pkg-default /opt/resolve/configs/config.dat
@@ -214,6 +252,44 @@ process16() {
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
 
+    # Create udev rules
+    create_directory ${DEB_DIR}/lib/udev/rules.d
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
+EOF
+
+    # Create desktop shortcuts
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec=/opt/resolve/bin/resolve
+Icon=/opt/resolve/graphics/DV_Resolve.png
+Name=${RESOLVE_NAME}
+Terminal=false
+MimeType=application/x-resolveproj;
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
+Icon=/opt/resolve/graphics/DV_Panels.png
+Name=DaVinci Resolve Panels Setup
+Terminal=false
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+
     # Add postinst commands
     cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
 chmod -R a+rw /opt/resolve/easyDCP
@@ -234,7 +310,99 @@ EOF
     fi
 }
 
-process16braw() {
+process17() {
+    # Create directories
+    create_directory ${RESOLVE_BASE_DIR}/easyDCP
+    create_directory ${RESOLVE_BASE_DIR}/scripts
+    create_directory ${RESOLVE_BASE_DIR}/.license
+    create_directory ${RESOLVE_BASE_DIR}/share
+    create_directory ${RESOLVE_BASE_DIR}/Fairlight
+
+    # Copy objects
+    copy_object ${UNPACK_DIR}/bin ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Control ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/DaVinci\ Control\ Panels\ Setup ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Developer ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/docs ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Fusion ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/graphics ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/libs ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/LUT ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/Onboarding ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/plugins ${RESOLVE_BASE_DIR}
+    if ! [[ "$RESOLVE_VERSION" == 16.0b* ]];
+    then
+	copy_object ${UNPACK_DIR}/Technical\ Documentation ${RESOLVE_BASE_DIR}
+    fi
+    copy_object ${UNPACK_DIR}/UI_Resource ${RESOLVE_BASE_DIR}
+    copy_object ${UNPACK_DIR}/scripts/script.checkfirmware ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/scripts/script.getlogs.v4 ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/scripts/script.start ${RESOLVE_BASE_DIR}/scripts/
+    copy_object ${UNPACK_DIR}/share/default-config.dat ${RESOLVE_BASE_DIR}/share/
+    copy_object ${UNPACK_DIR}/share/log-conf.xml ${RESOLVE_BASE_DIR}/share/
+    copy_object ${UNPACK_DIR}/share/default_cm_config.bin ${RESOLVE_BASE_DIR}/share/
+
+    # Extract panel API library
+    create_directory ${DEB_DIR}/usr/lib
+    extract_tgz ${UNPACK_DIR}/share/panels/dvpanel-framework-linux-x86_64.tgz ${DEB_DIR}/usr/lib libDaVinciPanelAPI.so
+
+    # Create symlinks
+    create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
+    link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
+    link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+
+    # Create common data dir
+    create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
+
+    # Create udev rules
+    create_directory ${DEB_DIR}/lib/udev/rules.d
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
+EOF
+    cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
+SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
+EOF
+
+    # Create desktop shortcuts
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec=/opt/resolve/bin/resolve
+Icon=/opt/resolve/graphics/DV_Resolve.png
+Name=${RESOLVE_NAME}
+Terminal=false
+MimeType=application/x-resolveproj;
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+    assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
+    cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Exec="/opt/resolve/DaVinci Control Panels Setup/DaVinci Control Panels Setup"
+Icon=/opt/resolve/graphics/DV_Panels.png
+Name=DaVinci Control Panels Setup
+Terminal=false
+Type=Application
+StartupNotify=true
+Categories=AudioVideo
+EOF
+
+    # Add postinst commands
+    cat >> ${DEB_DIR}/DEBIAN/postinst <<EOF
+chmod -R a+rw /opt/resolve/easyDCP
+chmod -R a+rw /opt/resolve/LUT
+chmod -R a+rw /opt/resolve/.license
+chmod -R a+rw /opt/resolve/Fairlight
+chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
+EOF
+}
+
+process1617braw() {
     if ! [[ -e ${UNPACK_DIR}/BlackmagicRAWPlayer ]]; then
 	return;
     fi
@@ -281,6 +449,33 @@ Categories=AudioVideo
 EOF
 }
 
+installer_extract_xorriso() {
+    # Extract archive
+    check_command xorriso
+    echo "Extracting archive"
+    createf_directory ${UNPACK_DIR}
+    xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
+    if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
+    then
+	echo "[ERROR] Failed to extract DaVinci Resolve archive"
+	remove_directory ${UNPACK_DIR}
+	exit 1
+    fi
+}
+
+installer_extract_native() {
+    # Extract archive
+    echo "Extracting archive"
+    createf_directory ${UNPACK_DIR}
+    ./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR} >/dev/null
+    if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
+    then
+	echo "[ERROR] Failed to extract DaVinci Resolve archive"
+	remove_directory ${UNPACK_DIR}
+	exit 1
+    fi
+}
+
 echo "MakeResolveDeb ${MAKERESOLVEDEB_VERSION}"
 
 # Check argument
@@ -340,22 +535,10 @@ echo
 
 # Verify that we have the commands we need
 check_command tar
-check_command xorriso
 check_command fakeroot
 check_command dpkg-deb
 echo
 
-# Extract archive
-echo "Extracting archive"
-createf_directory ${UNPACK_DIR}
-xorriso -osirrox on -indev ${INSTALLER_ARCHIVE} -extract / ${UNPACK_DIR}
-if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
-then
-    echo "[ERROR] Failed to extract DaVinci Resolve archive"
-    remove_directory ${UNPACK_DIR}
-    exit 1
-fi
-
 # Create destination directories
 createf_directory ${DEB_DIR}
 createf_directory ${RESOLVE_BASE_DIR}
@@ -367,59 +550,30 @@ init_deb
 case $RESOLVE_VERSION in
     15.*)
 	echo "Using Resolve 15 conversion process"
+	installer_extract_xorriso
 	process15
 	;;
     16.*)
 	echo "Using Resolve 16 conversion process"
+	installer_extract_native
 	process16
-	process16braw
+	process1617braw
+	;;
+    17.*)
+	echo "Using Resolve 17 conversion process"
+	installer_extract_native
+	process17
+	process1617braw
 	;;
     *)
 	echo "Unknown Resolve version"
-	echo "Trying Resolve 16 conversion process"
-	process16
-	process16braw
+	echo "Trying Resolve 17 conversion process"
+	installer_extract_native
+	process17
+	process1617braw
 	;;
 esac
 
-# Create udev rules
-create_directory ${DEB_DIR}/lib/udev/rules.d
-cat > ${DEB_DIR}/lib/udev/rules.d/75-davincipanel.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="1edb", MODE="0666"
-EOF
-cat > ${DEB_DIR}/lib/udev/rules.d/75-sdx.rules <<EOF
-SUBSYSTEM=="usb", ENV{DEVTYPE}=="usb_device", ATTRS{idVendor}=="096e", MODE="0666"
-EOF
-
-# Create desktop shortcuts
-assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Resolve.png
-cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec=/opt/resolve/bin/resolve
-Icon=/opt/resolve/graphics/DV_Resolve.png
-Name=${RESOLVE_NAME}
-Terminal=false
-MimeType=application/x-resolveproj;
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-assert_object ${DEB_DIR}/opt/resolve/graphics/DV_Panels.png
-cat > ${DEB_DIR}/usr/share/applications/${DEB_NAME}-panel-setup.desktop <<EOF
-[Desktop Entry]
-Version=1.0
-Encoding=UTF-8
-Exec="/opt/resolve/DaVinci Resolve Panels Setup/DaVinci Resolve Panels Setup"
-Icon=/opt/resolve/graphics/DV_Panels.png
-Name=DaVinci Resolve Panels Setup
-Terminal=false
-Type=Application
-StartupNotify=true
-Categories=AudioVideo
-EOF
-
 # Create Debian package
 close_deb
 echo "Creating Debian package"
